==> openhab-4.3.5.tar.gz: java/org/openhab/core/thing/internal/dto/XmlThingType.java <==

package org.openhab.core.thing.internal.dto;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.annotation.Generated;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import org.openhab.core.config.core.dto.XmlConfigDescription;
import org.openhab.core.config.core.dto.XmlConfigDescriptionRef;


/**
 * <p>Java class for thingType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="thingType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="supported-bridge-type-refs" type="{https://openhab.org/schemas/thing-description/v1.0.0}supportedBridgeTypeRefs" minOccurs="0"/&gt;
 *         &lt;element name="label" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="description" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="category" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;choice minOccurs="0"&gt;
 *           &lt;element name="channels" type="{https://openhab.org/schemas/thing-description/v1.0.0}channels"/&gt;
 *           &lt;element name="channel-groups" type="{https://openhab.org/schemas/thing-description/v1.0.0}channelGroups"/&gt;
 *         &lt;/choice&gt;
 *         &lt;element name="properties" type="{https://openhab.org/schemas/thing-description/v1.0.0}properties" minOccurs="0"/&gt;
 *         &lt;element name="representation-property" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;choice minOccurs="0"&gt;
 *           &lt;element name="config-description" type="{https://openhab.org/schemas/config-description/v1.0.0}configDescription"/&gt;
 *           &lt;element name="config-description-ref" type="{https://openhab.org/schemas/config-description/v1.0.0}configDescriptionRef"/&gt;
 *         &lt;/choice&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="id" use="required" type="{https://openhab.org/schemas/config-description/v1.0.0}idRestrictionPattern" /&gt;
 *       &lt;attribute name="listed" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *       &lt;attribute name="extensible" type="{https://openhab.org/schemas/thing-description/v1.0.0}namespaceIdListRestrictionPattern" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "thingType", propOrder = {
    "supportedBridgeTypeRefs",
    "label",
    "description",
    "category",
    "channels",
    "channelGroups",
    "properties",
    "representationProperty",
    "configDescription",
    "configDescriptionRef"
})
@XmlSeeAlso({
    XmlBridgeType.class
})
@Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
public class XmlThingType implements Serializable
{

    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    private final static long serialVersionUID = 1L;
    @XmlElementWrapper(name = "supported-bridge-type-refs")
    @XmlElement(name = "bridge-type-ref")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    protected List<XmlBridgeTypeRef> supportedBridgeTypeRefs = new ArrayList<XmlBridgeTypeRef>();
    @XmlElement(required = true)
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    protected String label;
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    protected String description;
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    protected String category;
    @XmlElementWrapper
    @XmlElement(name = "channel")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    protected List<XmlChannel> channels = new ArrayList<XmlChannel>();
    @XmlElementWrapper(name = "channel-groups")
    @XmlElement(name = "channel-group")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    protected List<XmlChannelGroup> channelGroups = new ArrayList<XmlChannelGroup>();
    @XmlElementWrapper
    @XmlElement(name = "property")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    protected List<XmlProperty> properties = new ArrayList<XmlProperty>();
    @XmlElement(name = "representation-property")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    protected String representationProperty;
    @XmlElement(name = "config-description")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    protected XmlConfigDescription configDescription;
    @XmlElement(name = "config-description-ref")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    protected XmlConfigDescriptionRef configDescriptionRef;
    @XmlAttribute(name = "id", required = true)
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    protected String id;
    @XmlAttribute(name = "listed")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    protected Boolean listed;
    @XmlAttribute(name = "extensible")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    protected String extensible;

    /**
     * Gets the value of the label property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public String getLabel() {
        return label;
    }

    /**
     * Sets the value of the label property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public void setLabel(String value) {
        this.label = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public String getDescription() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public void setDescription(String value) {
        this.description = value;
    }

    /**
     * Gets the value of the category property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public String getCategory() {
        return category;
    }

    /**
     * Sets the value of the category property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public void setCategory(String value) {
        this.category = value;
    }

    /**
     * Gets the value of the representationProperty property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public String getRepresentationProperty() {
        return representationProperty;
    }

    /**
     * Sets the value of the representationProperty property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public void setRepresentationProperty(String value) {
        this.representationProperty = value;
    }

    /**
     * Gets the value of the configDescription property.
     * 
     * @return
     *     possible object is
     *     {@link XmlConfigDescription }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public XmlConfigDescription getConfigDescription() {
        return configDescription;
    }

    /**
     * Sets the value of the configDescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link XmlConfigDescription }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public void setConfigDescription(XmlConfigDescription value) {
        this.configDescription = value;
    }

    /**
     * Gets the value of the configDescriptionRef property.
     * 
     * @return
     *     possible object is
     *     {@link XmlConfigDescriptionRef }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public XmlConfigDescriptionRef getConfigDescriptionRef() {
        return configDescriptionRef;
    }

    /**
     * Sets the value of the configDescriptionRef property.
     * 
     * @param value
     *     allowed object is
     *     {@link XmlConfigDescriptionRef }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public void setConfigDescriptionRef(XmlConfigDescriptionRef value) {
        this.configDescriptionRef = value;
    }

    /**
     * Gets the value of the id property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public String getId() {
        return id;
    }

    /**
     * Sets the value of the id property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Gets the value of the listed property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public boolean isListed() {
        if (listed == null) {
            return true;
        } else {
            return listed;
        }
    }

    /**
     * Sets the value of the listed property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public void setListed(Boolean value) {
        this.listed = value;
    }

    /**
     * Gets the value of the extensible property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public String getExtensible() {
        return extensible;
    }

    /**
     * Sets the value of the extensible property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public void setExtensible(String value) {
        this.extensible = value;
    }

    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public List<XmlBridgeTypeRef> getSupportedBridgeTypeRefs() {
        return supportedBridgeTypeRefs;
    }

    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public void setSupportedBridgeTypeRefs(List<XmlBridgeTypeRef> supportedBridgeTypeRefs) {
        this.supportedBridgeTypeRefs = supportedBridgeTypeRefs;
    }

    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public List<XmlChannel> getChannels() {
        return channels;
    }

    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public void setChannels(List<XmlChannel> channels) {
        this.channels = channels;
    }

    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public List<XmlChannelGroup> getChannelGroups() {
        return channelGroups;
    }

    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public void setChannelGroups(List<XmlChannelGroup> channelGroups) {
        this.channelGroups = channelGroups;
    }

    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public List<XmlProperty> getProperties() {
        return properties;
    }

    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-04-26T13:36:10Z")
    public void setProperties(List<XmlProperty> properties) {
        this.properties = properties;
    }

}

==> openhab-5.0.0.tar.gz: java/org/openhab/core/thing/internal/dto/XmlThingType.java <==

package org.openhab.core.thing.internal.dto;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.annotation.Generated;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import org.openhab.core.config.core.dto.XmlConfigDescription;
import org.openhab.core.config.core.dto.XmlConfigDescriptionRef;


/**
 * <p>Java class for thingType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="thingType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="supported-bridge-type-refs" type="{https://openhab.org/schemas/thing-description/v1.0.0}supportedBridgeTypeRefs" minOccurs="0"/&gt;
 *         &lt;element name="label" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="description" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="category" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="semantic-equipment-tag" type="{https://openhab.org/schemas/thing-description/v1.0.0}semanticEquipmentTag" minOccurs="0"/&gt;
 *         &lt;choice minOccurs="0"&gt;
 *           &lt;element name="channels" type="{https://openhab.org/schemas/thing-description/v1.0.0}channels"/&gt;
 *           &lt;element name="channel-groups" type="{https://openhab.org/schemas/thing-description/v1.0.0}channelGroups"/&gt;
 *         &lt;/choice&gt;
 *         &lt;element name="properties" type="{https://openhab.org/schemas/thing-description/v1.0.0}properties" minOccurs="0"/&gt;
 *         &lt;element name="representation-property" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;choice minOccurs="0"&gt;
 *           &lt;element name="config-description" type="{https://openhab.org/schemas/config-description/v1.0.0}configDescription"/&gt;
 *           &lt;element name="config-description-ref" type="{https://openhab.org/schemas/config-description/v1.0.0}configDescriptionRef"/&gt;
 *         &lt;/choice&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="id" use="required" type="{https://openhab.org/schemas/config-description/v1.0.0}idRestrictionPattern" /&gt;
 *       &lt;attribute name="listed" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *       &lt;attribute name="extensible" type="{https://openhab.org/schemas/thing-description/v1.0.0}namespaceIdListRestrictionPattern" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "thingType", propOrder = {
    "supportedBridgeTypeRefs",
    "label",
    "description",
    "category",
    "semanticEquipmentTag",
    "channels",
    "channelGroups",
    "properties",
    "representationProperty",
    "configDescription",
    "configDescriptionRef"
})
@XmlSeeAlso({
    XmlBridgeType.class
})
@Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
public class XmlThingType implements Serializable
{

    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    private final static long serialVersionUID = 1L;
    @XmlElementWrapper(name = "supported-bridge-type-refs")
    @XmlElement(name = "bridge-type-ref")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    protected List<XmlBridgeTypeRef> supportedBridgeTypeRefs = new ArrayList<XmlBridgeTypeRef>();
    @XmlElement(required = true)
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    protected String label;
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    protected String description;
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    protected String category;
    @XmlElement(name = "semantic-equipment-tag")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    protected String semanticEquipmentTag;
    @XmlElementWrapper
    @XmlElement(name = "channel")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    protected List<XmlChannel> channels = new ArrayList<XmlChannel>();
    @XmlElementWrapper(name = "channel-groups")
    @XmlElement(name = "channel-group")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    protected List<XmlChannelGroup> channelGroups = new ArrayList<XmlChannelGroup>();
    @XmlElementWrapper
    @XmlElement(name = "property")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    protected List<XmlProperty> properties = new ArrayList<XmlProperty>();
    @XmlElement(name = "representation-property")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    protected String representationProperty;
    @XmlElement(name = "config-description")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    protected XmlConfigDescription configDescription;
    @XmlElement(name = "config-description-ref")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    protected XmlConfigDescriptionRef configDescriptionRef;
    @XmlAttribute(name = "id", required = true)
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    protected String id;
    @XmlAttribute(name = "listed")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    protected Boolean listed;
    @XmlAttribute(name = "extensible")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    protected String extensible;

    /**
     * Gets the value of the label property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public String getLabel() {
        return label;
    }

    /**
     * Sets the value of the label property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public void setLabel(String value) {
        this.label = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public String getDescription() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public void setDescription(String value) {
        this.description = value;
    }

    /**
     * Gets the value of the category property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public String getCategory() {
        return category;
    }

    /**
     * Sets the value of the category property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public void setCategory(String value) {
        this.category = value;
    }

    /**
     * Gets the value of the semanticEquipmentTag property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public String getSemanticEquipmentTag() {
        return semanticEquipmentTag;
    }

    /**
     * Sets the value of the semanticEquipmentTag property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public void setSemanticEquipmentTag(String value) {
        this.semanticEquipmentTag = value;
    }

    /**
     * Gets the value of the representationProperty property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public String getRepresentationProperty() {
        return representationProperty;
    }

    /**
     * Sets the value of the representationProperty property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public void setRepresentationProperty(String value) {
        this.representationProperty = value;
    }

    /**
     * Gets the value of the configDescription property.
     * 
     * @return
     *     possible object is
     *     {@link XmlConfigDescription }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public XmlConfigDescription getConfigDescription() {
        return configDescription;
    }

    /**
     * Sets the value of the configDescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link XmlConfigDescription }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public void setConfigDescription(XmlConfigDescription value) {
        this.configDescription = value;
    }

    /**
     * Gets the value of the configDescriptionRef property.
     * 
     * @return
     *     possible object is
     *     {@link XmlConfigDescriptionRef }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public XmlConfigDescriptionRef getConfigDescriptionRef() {
        return configDescriptionRef;
    }

    /**
     * Sets the value of the configDescriptionRef property.
     * 
     * @param value
     *     allowed object is
     *     {@link XmlConfigDescriptionRef }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public void setConfigDescriptionRef(XmlConfigDescriptionRef value) {
        this.configDescriptionRef = value;
    }

    /**
     * Gets the value of the id property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public String getId() {
        return id;
    }

    /**
     * Sets the value of the id property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Gets the value of the listed property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public boolean isListed() {
        if (listed == null) {
            return true;
        } else {
            return listed;
        }
    }

    /**
     * Sets the value of the listed property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public void setListed(Boolean value) {
        this.listed = value;
    }

    /**
     * Gets the value of the extensible property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public String getExtensible() {
        return extensible;
    }

    /**
     * Sets the value of the extensible property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public void setExtensible(String value) {
        this.extensible = value;
    }

    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public List<XmlBridgeTypeRef> getSupportedBridgeTypeRefs() {
        return supportedBridgeTypeRefs;
    }

    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public void setSupportedBridgeTypeRefs(List<XmlBridgeTypeRef> supportedBridgeTypeRefs) {
        this.supportedBridgeTypeRefs = supportedBridgeTypeRefs;
    }

    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public List<XmlChannel> getChannels() {
        return channels;
    }

    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public void setChannels(List<XmlChannel> channels) {
        this.channels = channels;
    }

    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public List<XmlChannelGroup> getChannelGroups() {
        return channelGroups;
    }

    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public void setChannelGroups(List<XmlChannelGroup> channelGroups) {
        this.channelGroups = channelGroups;
    }

    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public List<XmlProperty> getProperties() {
        return properties;
    }

    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-07-21T07:00:44Z")
    public void setProperties(List<XmlProperty> properties) {
        this.properties = properties;
    }

}
